@@ -2,12 +2,18 @@ import argparse
 import logging
 import sys
 from functools import partial
+from typing import List
 
 import argcomplete
 from decli import cli
 
-from commitizen import commands, config
-from commitizen.exceptions import CommitizenException, ExpectedExit, NoCommandFoundError
+from commitizen import commands, config, out
+from commitizen.exceptions import (
+    CommitizenException,
+    ExitCode,
+    ExpectedExit,
+    NoCommandFoundError,
+)
 
 logger = logging.getLogger(__name__)
 data = {
@@ -24,6 +30,12 @@ data = {
             "name": ["-n", "--name"],
             "help": "use the given commitizen (default: cz_conventional_commits)",
         },
+        {
+            "name": ["-nr", "--no-raise"],
+            "type": str,
+            "required": False,
+            "help": "comma separated error codes that won't rise error, e.g: cz -nr 1,2,3 bump. See codes at https://commitizen-tools.github.io/commitizen/exit_codes/",
+        },
     ],
     "subcommands": {
         "title": "commands",
@@ -274,13 +286,20 @@ data = {
 original_excepthook = sys.excepthook
 
 
-def commitizen_excepthook(type, value, tracekback, debug=False):
+def commitizen_excepthook(
+    type, value, tracekback, debug=False, no_raise: List[int] = None
+):
+    if not no_raise:
+        no_raise = []
     if isinstance(value, CommitizenException):
         if value.message:
             value.output_method(value.message)
         if debug:
             original_excepthook(type, value, tracekback)
-        sys.exit(value.exit_code)
+        exit_code = value.exit_code
+        if exit_code in no_raise:
+            exit_code = 0
+        sys.exit(exit_code)
     else:
         original_excepthook(type, value, tracekback)
 
@@ -290,6 +309,28 @@ commitizen_debug_excepthook = partial(commitizen_excepthook, debug=True)
 sys.excepthook = commitizen_excepthook
 
 
+def parse_no_raise(comma_separated_no_raise: str) -> List[int]:
+    """Convert the given string to exit codes.
+
+    Receives digits and strings and outputs the parsed integer which
+    represents the exit code found in exceptions.
+    """
+    no_raise_items: List[str] = comma_separated_no_raise.split(",")
+    no_raise_codes = []
+    for item in no_raise_items:
+        if item.isdecimal():
+            no_raise_codes.append(int(item))
+            continue
+        try:
+            exit_code = ExitCode[item.strip()]
+        except KeyError:
+            out.warn(f"WARN: no_raise key `{item}` does not exist. Skipping.")
+            continue
+        else:
+            no_raise_codes.append(exit_code.value)
+    return no_raise_codes
+
+
 def main():
     conf = config.read_cfg()
     parser = cli(data)
@@ -319,6 +360,12 @@ def main():
     if args.debug:
         logging.getLogger("commitizen").setLevel(logging.DEBUG)
         sys.excepthook = commitizen_debug_excepthook
+    elif args.no_raise:
+        no_raise_exit_codes = parse_no_raise(args.no_raise)
+        no_raise_debug_excepthook = partial(
+            commitizen_excepthook, no_raise=no_raise_exit_codes
+        )
+        sys.excepthook = no_raise_debug_excepthook
 
     args.func(conf, vars(args))()
 
